@@ -20,7 +20,7 @@ class CondaDepOption(DepOption):
 
 def get_py_version(envconfig, action):
     # Try to use basepython
-    match = re.match(r"python(\d)(?:\.(\d))?(?:\.(\d))?", envconfig.basepython)
+    match = re.match(r"python(\d)(?:\.(\d))?(?:\.?(\d))?", envconfig.basepython)
     if match:
         groups = match.groups()
         version = groups[0]
@@ -57,6 +57,18 @@ def tox_addoption(parser):
         name="conda_channels", type="line-list", help="each line specifies a conda channel"
     )
 
+    parser.add_testenv_attribute(
+        name="conda_install_args",
+        type="line-list",
+        help="each line specifies a conda install argument",
+    )
+
+    parser.add_testenv_attribute(
+        name="conda_create_args",
+        type="line-list",
+        help="each line specifies a conda create argument",
+    )
+
 
 @hookimpl
 def tox_configure(config):
@@ -118,6 +130,10 @@ def tox_testenv_create(venv, action):
         args = [conda_exe, "create", "--yes", "-p", envdir]
         for channel in venv.envconfig.conda_channels:
             args += ["--channel", channel]
+
+        # Add end-user conda create args
+        args += venv.envconfig.conda_create_args
+
         args += [python]
 
     venv._pcall(args, venv=False, action=action, cwd=basepath)
@@ -148,6 +164,10 @@ def install_conda_deps(venv, action, basepath, envdir):
     args = [conda_exe, "install", "--quiet", "--yes", "-p", envdir]
     for channel in venv.envconfig.conda_channels:
         args += ["--channel", channel]
+
+    # Add end-user conda install args
+    args += venv.envconfig.conda_install_args
+
     # We include the python version in the conda requirements in order to make
     # sure that none of the other conda requirements inadvertently downgrade
     # python in this environment. If any of the requirements are in conflict
